@@ -86,7 +86,7 @@ class AcceptAction(object):
         """
         return bool(self.handler)
 
-    def validate_and_handle(self, cli, buffer):
+    def validate_and_handle(self, cli, buffer,put_in_history=True):
         """
         Validate buffer and handle the accept action.
         """
@@ -95,7 +95,8 @@ class AcceptAction(object):
         if buffer.validate():
             if self.handler:
                 self.handler(cli, buffer)
-            buffer.append_to_history()
+            if put_in_history:
+                buffer.append_to_history()
 
 def _return_document_handler(cli, buffer):
     # Set return value.
@@ -506,7 +507,7 @@ class Buffer(object):
 
     # End of <getters/setters>
 
-    def save_to_undo_stack(self, clear_redo_stack=True):
+    def save_to_undo_stack(self, clear_redo_stack=False):
         """
         Safe current state (input text and cursor position), so that we can
         restore it by calling undo.
@@ -605,12 +606,12 @@ class Buffer(object):
         # Remember the original column for the next up/down movement.
         self.preferred_column = original_column
 
-    def auto_up(self, count=1, go_to_start_of_line_if_history_changes=False):
+    def auto_up(self, count=1, go_to_start_of_line_if_history_changes=False,ryan_allow_completion_navigation=True):
         """
         If we're not on the first line (of a multiline input) go a line up,
         otherwise go back in history. (If nothing is selected.)
         """
-        if self.complete_state:
+        if self.complete_state and ryan_allow_completion_navigation:
             self.complete_previous(count=count)
         elif self.document.cursor_position_row > 0:
             self.cursor_up(count=count)
@@ -621,12 +622,12 @@ class Buffer(object):
             if go_to_start_of_line_if_history_changes:
                 self.cursor_position += self.document.get_start_of_line_position()
 
-    def auto_down(self, count=1, go_to_start_of_line_if_history_changes=False):
+    def auto_down(self, count=1, go_to_start_of_line_if_history_changes=False,ryan_allow_completion_navigation=True):
         """
         If we're not on the last line (of a multiline input) go a line down,
         otherwise go forward in history. (If nothing is selected.)
         """
-        if self.complete_state:
+        if self.complete_state and ryan_allow_completion_navigation:
             self.complete_next(count=count)
         elif self.document.cursor_position_row < self.document.line_count - 1:
             self.cursor_down(count=count)
@@ -656,6 +657,39 @@ class Buffer(object):
 
         return deleted
 
+    def set_cursor_column(self,column_number:int):
+        self.cursor_left(999999999)
+        self.cursor_right(column_number)
+
+
+
+    def set_cursor_row(self,row_number:int):
+        self.cursor_up(999999999)
+        self.cursor_down(row_number)
+
+
+    def delete_line_at_cursor(self, count=1):
+
+        def delete_current_line(buffer):
+            document=buffer.document
+            current_line=document.current_line
+            buffer.cursor_left(10000)
+            firstline=buffer.cursor_position==0
+            buffer.delete(len(current_line))
+            buffer.delete_before_cursor()
+            if firstline:
+                buffer.delete()
+            else:
+                buffer.cursor_down()
+
+        cursor_column=self.document.cursor_position_col
+
+        for _ in range(count):
+            delete_current_line(self)
+
+        self.set_cursor_column(cursor_column)
+
+
     def delete(self, count=1):
         """
         Delete specified number of characters and Return the deleted text.
@@ -668,6 +702,37 @@ class Buffer(object):
         else:
             return ''
 
+
+    def delete_line_above_cursor(self, count=1):
+        cursor_column=self.document.cursor_position_col
+
+        for _ in range(count):
+            if '\n' not in self.document.text_before_cursor:
+                #There are no lines above this line. Stop here.
+                break
+            self.cursor_up()
+            self.delete_line_at_cursor()
+
+        self.set_cursor_column(cursor_column)
+
+    def delete_line_below_cursor(self, count=1):
+        cursor_column=self.document.cursor_position_col
+
+        for _ in range(count):
+            if '\n' not in self.document.text_after_cursor:
+                #If our cursor is on the last line, stop here.
+                break
+
+            deleting_last_line=self.document.text_after_cursor.count('\n')==1
+            self.cursor_down()
+            self.delete_line_at_cursor()
+
+            if not deleting_last_line:
+                #If we're not deleting the last line, we have to move the cursor back up manually
+                self.cursor_up()
+
+        self.set_cursor_column(cursor_column)
+
     def join_next_line(self, separator=' '):
         """
         Join the next line to the current one by deleting the line ending after
@@ -1081,6 +1146,7 @@ class Buffer(object):
             self.on_text_insert.fire()
 
     def undo(self):
+        from rp import ring_terminal_bell
         # Pop from the undo-stack until we find a text that if different from
         # the current text. (The current logic of `save_to_undo_stack` will
         # cause that the top of the undo stack is usually the same as the
@@ -1090,20 +1156,25 @@ class Buffer(object):
 
             if text != self.text:
                 # Push current text to redo stack.
+                # ring_terminal_bell()
                 self._redo_stack.append((self.text, self.cursor_position))
-
+                # print(self._redo_stack)
                 # Set new text/cursor_position.
                 self.document = Document(text, cursor_position=pos)
                 break
 
     def redo(self):
+        # from rp import ring_terminal_bell,text_to_speech
         if self._redo_stack:
             # Copy current state on undo stack.
+            # ring_terminal_bell()
             self.save_to_undo_stack(clear_redo_stack=False)
 
             # Pop state from redo stack.
             text, pos = self._redo_stack.pop()
             self.document = Document(text, cursor_position=pos)
+        # else:
+        #     text_to_speech("FAILED")
 
     def validate(self):
         """
@@ -1144,6 +1215,7 @@ class Buffer(object):
         # history is already the same.)
         if self.text and (not len(self.history) or self.history[-1] != self.text):
             self.history.append(self.text)
+            self.history.append_with_metadata(self)
 
     def _search(self, search_state, include_current_position=False, count=1):
         """
@@ -1324,9 +1396,11 @@ class Buffer(object):
 
             # Order of preference.
             '/usr/bin/editor',
+            '/usr/bin/vi',
+            '/usr/bin/micro',
+            '/usr/bin/suplemon',
             '/usr/bin/nano',
             '/usr/bin/pico',
-            '/usr/bin/vi',
             '/usr/bin/emacs',
         ]
 
