@@ -3,25 +3,23 @@ Creation of the `Layout` instance for the Python input/REPL.
 """
 from __future__ import unicode_literals
 
-from rp.prompt_toolkit.enums import DEFAULT_BUFFER, SEARCH_BUFFER
-from rp.prompt_toolkit.filters import IsDone, HasCompletions, RendererHeightIsKnown, HasFocus, Condition
-from rp.prompt_toolkit.key_binding.vi_state import InputMode
-from rp.prompt_toolkit.layout.containers import Window, HSplit, VSplit, FloatContainer, Float, ConditionalContainer, ScrollOffsets
-from rp.prompt_toolkit.layout.controls import BufferControl, TokenListControl, FillControl, UIContent
-from rp.prompt_toolkit.layout.dimension import LayoutDimension
-from rp.prompt_toolkit.layout.lexers import SimpleLexer
-from rp.prompt_toolkit.layout.margins import PromptMargin
-from rp.prompt_toolkit.layout.menus import CompletionsMenu, MultiColumnCompletionsMenu
-from rp.prompt_toolkit.layout.processors import ConditionalProcessor, AppendAutoSuggestion, HighlightSearchProcessor, HighlightSelectionProcessor, HighlightMatchingBracketProcessor, Processor, Transformation
-from rp.prompt_toolkit.layout.screen import Char
-from rp.prompt_toolkit.layout.toolbars import CompletionsToolbar, ArgToolbar, SearchToolbar, ValidationToolbar, SystemToolbar, TokenListToolbar
-from rp.prompt_toolkit.layout.utils import token_list_width
-from rp.prompt_toolkit.reactive import Integer
-from rp.prompt_toolkit.selection import SelectionType
-from rp.prompt_toolkit.document import Document
-from rp.prompt_toolkit.selection import SelectionState
+from prompt_toolkit.enums import DEFAULT_BUFFER, SEARCH_BUFFER
+from prompt_toolkit.filters import IsDone, HasCompletions, RendererHeightIsKnown, HasFocus, Condition
+from prompt_toolkit.key_binding.vi_state import InputMode
+from prompt_toolkit.layout.containers import Window, HSplit, VSplit, FloatContainer, Float, ConditionalContainer, ScrollOffsets
+from prompt_toolkit.layout.controls import BufferControl, TokenListControl, FillControl
+from prompt_toolkit.layout.dimension import LayoutDimension
+from prompt_toolkit.layout.lexers import SimpleLexer
+from prompt_toolkit.layout.margins import PromptMargin
+from prompt_toolkit.layout.menus import CompletionsMenu, MultiColumnCompletionsMenu
+from prompt_toolkit.layout.processors import ConditionalProcessor, AppendAutoSuggestion, HighlightSearchProcessor, HighlightSelectionProcessor, HighlightMatchingBracketProcessor, Processor, Transformation
+from prompt_toolkit.layout.screen import Char
+from prompt_toolkit.layout.toolbars import CompletionsToolbar, ArgToolbar, SearchToolbar, ValidationToolbar, SystemToolbar, TokenListToolbar
+from prompt_toolkit.layout.utils import token_list_width
+from prompt_toolkit.reactive import Integer
+from prompt_toolkit.selection import SelectionType
 
-from .filters import HasSignature, ShowSidebar, ShowSignature, ShowDocstring,ShowRealtimeInput,ShowVarSpace,ShowVarSpaceAndShowRealtimeInput,ShowVarSpaceOrShowRealtimeInput,ShowParenthesisAutomator
+from .filters import HasSignature, ShowSidebar, ShowSignature, ShowDocstring
 from .utils import if_mousedown
 
 from pygments.lexers import PythonLexer
@@ -36,9 +34,9 @@ __all__ = (
 )
 
 
-# DisplayMultipleCursors: Only for rp.prompt_toolkit>=1.0.8
+# DisplayMultipleCursors: Only for prompt_toolkit>=1.0.8
 try:
-    from rp.prompt_toolkit.layout.processors import DisplayMultipleCursors
+    from prompt_toolkit.layout.processors import DisplayMultipleCursors
 except ImportError:
     class DisplayMultipleCursors(Processor):
         " Dummy. "
@@ -217,7 +215,7 @@ def signature_toolbar(python_input):
             append((Signature, ' '))
             try:
                 append((Signature, sig.full_name))
-            except:# IndexError but Also AttributeError: 'NoneType' object has no attribute 'split'
+            except IndexError:
                 # Workaround for #37: https://github.com/jonathanslenders/python-prompt-toolkit/issues/37
                 # See also: https://github.com/davidhalter/jedi/issues/490
                 return []
@@ -239,17 +237,12 @@ def signature_toolbar(python_input):
                 description = (p.description if p else '*') #or '*'
                 sig_index = getattr(sig, 'index', 0)
 
-                #region Ryan Burgert Code (it was annoying seeing f(param x,param y) etc. So I got rid of the 'param' stuff and now it looks nicer
-                desc_string=str(description)
-                if desc_string.startswith("param "):
-                    desc_string=desc_string[6:]
-                #endregion
                 if i == sig_index:
                     # Note: we use `_Param.description` instead of
                     #       `_Param.name`, that way we also get the '*' before args.
-                    append((Signature.CurrentName,desc_string))
+                    append((Signature.CurrentName, str(description)))
                 else:
-                    append((Signature,desc_string))
+                    append((Signature, str(description)))
                 append((Signature.Operator, ', '))
 
             if sig.params:
@@ -303,10 +296,6 @@ def status_bar(python_input):
     """
     TB = Token.Toolbar.Status
 
-    @if_mousedown
-    def toggle_mouse_support(cli, mouse_event):
-        python_input.enable_mouse_support = not python_input.enable_mouse_support
-
     @if_mousedown
     def toggle_paste_mode(cli, mouse_event):
         python_input.paste_mode = not python_input.paste_mode
@@ -338,23 +327,15 @@ def status_bar(python_input):
         else:
             result.extend([
                 (TB.Key, '[F3]', enter_history),
-                (TB, 'History ', enter_history),
+                (TB, ' History ', enter_history),
                 (TB.Key, '[F6]', toggle_paste_mode),
-                # (TB, ' ', toggle_paste_mode),
+                (TB, ' ', toggle_paste_mode),
             ])
 
             if python_input.paste_mode:
-                append((TB.PasteModeOn, 'Paste:On  ', toggle_paste_mode))
+                append((TB.PasteModeOn, 'Paste mode (on)', toggle_paste_mode))
             else:
-                append((TB, 'Paste:Off ', toggle_paste_mode))
-
-            result.extend([
-                (TB.Key, '[F1]', toggle_mouse_support),
-            ])
-            if python_input.enable_mouse_support:
-                append((TB.PasteModeOn, 'Mouse:On  ', toggle_mouse_support))
-            else:
-                append((TB, 'Mouse:Off ', toggle_mouse_support))
+                append((TB, 'Paste mode', toggle_paste_mode))
         #region RYAN BURGERT CODE GOES HERE FOR PSEUDOTERMINAL STUFF
         append((TB, ' '))
         @if_mousedown
@@ -362,7 +343,7 @@ def status_bar(python_input):
             # python_input.enter_history(cli)
             pass
         import rp.r_iterm_comm
-        append((TB.PseudoTerminalCurrentVariable,repr(rp.r_iterm_comm.last_assignable_comm),testytest))
+        append((TB,repr(rp.r_iterm_comm.last_assignable_comm),testytest))
         append((TB, ' '))
         return result
 
@@ -373,7 +354,7 @@ def status_bar(python_input):
             Condition(lambda cli: python_input.show_status_bar and
                                   not python_input.show_exit_confirmation))
 
-selection_flag=False
+
 def get_inputmode_tokens(cli, python_input):
     """
     Return current input mode as a list of (token, text) tuples for use in a
@@ -393,38 +374,15 @@ def get_inputmode_tokens(cli, python_input):
 
     append((token.InputMode, '[F4] ', toggle_vi_mode))
 
-    #region  RYAN BURGERT CODE: This code is called every time the user makes a selection. I'm going to use this to chage the selection area to make more sense (in my opinion)
-    global selection_flag
-    buffer=cli.current_buffer
-    has_selection=bool(buffer.selection_state)# Handling on_new_selection...
-    if has_selection and not selection_flag:# We made a new selection
-        document=buffer.document
-        assert isinstance(document,Document)
-        assert isinstance(document._selection,SelectionState)
-        #
-        cursor,cursor_orig=document.cursor_position,document._selection.original_cursor_position
-        if cursor>cursor_orig:
-            cursor-=1
-        elif cursor<cursor_orig:
-            cursor_orig-=1
-        #
-        buffer.document=Document(document.text,cursor_position=cursor,selection=None)
-        buffer.document._selection=SelectionState(original_cursor_position=cursor_orig,type=document.selection.type)
-        #
-        # from rp import text_to_speech
-        # text_to_speech("HI")# For debugging
-    selection_flag=has_selection
-    #endregion
-
     # InputMode
     if python_input.vi_mode:
-        if has_selection:
-            if buffer.selection_state.type == SelectionType.LINES:
+        if bool(cli.current_buffer.selection_state):
+            if cli.current_buffer.selection_state.type == SelectionType.LINES:
                 append((token.InputMode, 'Vi (VISUAL LINE)', toggle_vi_mode))
-            elif buffer.selection_state.type == SelectionType.CHARACTERS:
+            elif cli.current_buffer.selection_state.type == SelectionType.CHARACTERS:
                 append((token.InputMode, 'Vi (VISUAL)', toggle_vi_mode))
                 append((token, ' '))
-            elif buffer.selection_state.type == 'BLOCK':
+            elif cli.current_buffer.selection_state.type == 'BLOCK':
                 append((token.InputMode, 'Vi (VISUAL BLOCK)', toggle_vi_mode))
                 append((token, ' '))
         elif mode in (InputMode.INSERT, 'vi-insert-multiple'):
@@ -456,28 +414,19 @@ def show_sidebar_button_info(python_input):
     token = Token.Toolbar.Status
 
     version = sys.version_info
-    import datetime
-    remove_beginning_zero=lambda x:x[1:] if x[0] == '0' else x
-    import rp
-    get_tokens=lambda cli: [
-
-
-        (token.BatteryPluggedIn if rp.battery_plugged_in() else token.BatteryNotPluggedIn,"🔋 "*0+str(rp.battery_percentage())+'%'),# put the time here
-        (token, ' '),
-        (token,(remove_beginning_zero(datetime.datetime.now().strftime("%I:%M%p")).lower())),# put the time here
-        (token, ' '),
+    tokens = [
         (token.Key, '[F2]', toggle_sidebar),
         (token, ' Menu', toggle_sidebar),
-        # (token, ' - '),
-        # (token.PythonVersion, '%s %i.%i.%i' % (platform.python_implementation(),
-        #                                        version[0], version[1], version[2])),
+        (token, ' - '),
+        (token.PythonVersion, '%s %i.%i.%i' % (platform.python_implementation(),
+                                               version[0], version[1], version[2])),
         (token, ' '),
     ]
-    width = token_list_width(get_tokens(None))
+    width = token_list_width(tokens)
 
-    # def get_tokens(cli):
-    #     Python version
-        # return tokens
+    def get_tokens(cli):
+        # Python version
+        return tokens
 
     return ConditionalContainer(
         content=Window(
@@ -541,7 +490,7 @@ def create_layout(python_input,
     extra_body = [extra_body] if extra_body else []
     extra_toolbars = extra_toolbars or []
     extra_buffer_processors = extra_buffer_processors or []
-    input_buffer_height = input_buffer_height or D(min=6)# This is the space between the input prompt and the toolbar. It lets the autocompletion menus have reaonable height.
+    input_buffer_height = input_buffer_height or D(min=6)
 
     def create_python_input_window():
         def menu_position(cli):
@@ -591,124 +540,67 @@ def create_layout(python_input,
                         else input_buffer_height)),
             wrap_lines=Condition(lambda cli: python_input.wrap_lines),
         )
-    def title_fill(title,fill=' ',style=Token.Window.TIItleV2):
-        height=title.count("\n")+1
-        import rp.r_iterm_comm
-        rp.r_iterm_comm.python_input_buffers[title]=title
-        try:
-            return VSplit([
-            Window(height=D.exact(height),content=FillControl(fill,token=style)),
-            Window(BufferControl(buffer_name=title,lexer=SimpleLexer(default_token=style),),wrap_lines=False,height=D.exact(height),width=D.exact(max(len(x)for x in title.split('\n')))),
-            Window(height=D.exact(height),content=FillControl(fill,token=style)),
-                    ])
-        except:
-            return Window(height=D.exact(1),content=FillControl(fill,token=Token.Separator))
-    import rp
+
     return HSplit([
-                      VSplit([
-                          HSplit([
-                              FloatContainer(
-                                  content=HSplit(
-                                      [create_python_input_window()] + extra_body
-                                  ),
-                                  floats=[
-                                      Float(xcursor=True,
-                                            ycursor=True,
-                                            content=CompletionsMenu(
-                                                scroll_offset=Integer.from_callable(
-                                                    lambda:python_input.completion_menu_scroll_offset),
-                                                max_height=12,
-                                                extra_filter=show_completions_menu(python_input))),
-                                      Float(xcursor=True,
-                                            ycursor=True,
-                                            content=MultiColumnCompletionsMenu(
-                                                extra_filter=show_multi_column_completions_menu(python_input))),
-                                      Float(xcursor=True,
-                                            ycursor=True,
-                                            content=signature_toolbar(python_input)),
-                                      Float(left=2,
-                                            bottom=1,
-                                            content=exit_confirmation(python_input)),
-                                      Float(bottom=0,right=0,height=1,
-                                            content=meta_enter_message(python_input),
-                                            hide_when_covering_content=True),
-                                      Float(bottom=1,left=1,right=0,content=python_sidebar_help(python_input)),
-                                  ]),
-                              ArgToolbar(),
-                              SearchToolbar(),
-                              SystemToolbar(),
-                              ValidationToolbar(),
-                              CompletionsToolbar(extra_filter=show_completions_toolbar(python_input)),
-                              # Docstring region.
-                              ConditionalContainer(
-                                  content=Window(height=D.exact(1),
-                                                 content=FillControl('\u2500',token=Token.Separator)),
-                                  filter=HasSignature(python_input) & ShowDocstring(python_input) & ~IsDone()),
-                              ConditionalContainer(
-                                  content=Window(
-                                      BufferControl(
-                                          buffer_name='docstring',
-                                          lexer=SimpleLexer(default_token=Token.Docstring),
-                                          # lexer=PythonLexer,
-                                      ),
-                                      height=D(max=12)),
-                                  filter=HasSignature(python_input) & ShowDocstring(python_input) & ~IsDone(),
-                              ),
-                              # realtime display region RYAN BURGERT CODE zone
-                              # ConditionalContainer(
-                              #     content=Window(height=D.exact(1),content=FillControl('\u2500',token=Token.Separator)),
-                              #     filter=ShowVarSpaceOrShowRealtimeInput(python_input) & ~IsDone()),
-                              ConditionalContainer(
+        VSplit([
+            HSplit([
+                FloatContainer(
+                    content=HSplit(
+                        [create_python_input_window()] + extra_body
+                    ),
+                    floats=[
+                        Float(xcursor=True,
+                              ycursor=True,
+                              content=CompletionsMenu(
+                                  scroll_offset=Integer.from_callable(
+                                      lambda: python_input.completion_menu_scroll_offset),
+                                  max_height=12,
+                                  extra_filter=show_completions_menu(python_input))),
+                        Float(xcursor=True,
+                              ycursor=True,
+                              content=MultiColumnCompletionsMenu(
+                                  extra_filter=show_multi_column_completions_menu(python_input))),
+                        Float(xcursor=True,
+                              ycursor=True,
+                              content=signature_toolbar(python_input)),
+                        Float(left=2,
+                              bottom=1,
+                              content=exit_confirmation(python_input)),
+                        Float(bottom=0, right=0, height=1,
+                              content=meta_enter_message(python_input),
+                              hide_when_covering_content=True),
+                        Float(bottom=1, left=1, right=0, content=python_sidebar_help(python_input)),
+                    ]),
+                ArgToolbar(),
+                SearchToolbar(),
+                SystemToolbar(),
+                ValidationToolbar(),
+                CompletionsToolbar(extra_filter=show_completions_toolbar(python_input)),
 
-
-                                  content=
-                                  HSplit([
-                                      # title_fill("Parenthesis Automator"),
-                                      # Window(BufferControl(buffer_name='parenthesizer_buffer',lexer=lexer,),wrap_lines=False,height=D(max=rp.r_iterm_comm.parenthesized_line.count('\n'),min=rp.r_iterm_comm.parenthesized_line.count('\n')    ))
-                                      Window(BufferControl(buffer_name='parenthesizer_buffer',lexer=lexer,),wrap_lines=False)
-                                      # title_fill(rp.r_iterm_comm.parenthesized_line),
-                                  ]),
-                                  filter=ShowParenthesisAutomator(python_input) & ~IsDone(),
-                              ),
-                              VSplit([
-                                  ConditionalContainer(
-                                      content=
-                                      HSplit([
-                                          # title_fill("Realtime Evaluator"),
-                                          Window(BufferControl(buffer_name='realtime_display',
-                                                               # lexer=SimpleLexer(default_token=Token.Docstring)
-                                                               lexer=lexer
-                                                               ,),wrap_lines=True,height=D(weight=2))
-                                      ]),
-                                      filter=ShowRealtimeInput(python_input) & ~IsDone(),
-                                  ),
-                                  ConditionalContainer(
-                                      content=Window(width=D.exact(1),
-                                                     content=FillControl('│',token=Token.Window.TIItleV2)),
-                                      filter=ShowVarSpaceAndShowRealtimeInput(python_input) & ~IsDone()),
-                                  ConditionalContainer(
-
-
-                                      content=
-                                      HSplit([
-                                          # title_fill("VARS"),
-                                          Window(BufferControl(buffer_name='vars',
-                                                               lexer=SimpleLexer(default_token=Token.Docstring)
-                                                               # lexer=lexer
-                                                               ,),wrap_lines=True)
-                                      ]),
-                                      filter=ShowVarSpace(python_input) & ~IsDone(),
-                                  ),
-                                ]),
-                          ]),
-                          HSplit([
-                              python_sidebar(python_input),
-                              python_sidebar_navigation(python_input),
-                          ])
-                      ]),
-                  ] + extra_toolbars + [
-                      VSplit([
-                          status_bar(python_input),
-                          show_sidebar_button_info(python_input),
-                      ])
-                  ])
+                # Docstring region.
+                ConditionalContainer(
+                    content=Window(height=D.exact(1),
+                                   content=FillControl('\u2500', token=Token.Separator)),
+                    filter=HasSignature(python_input) & ShowDocstring(python_input) & ~IsDone()),
+                ConditionalContainer(
+                    content=Window(
+                        BufferControl(
+                            buffer_name='docstring',
+                            lexer=SimpleLexer(default_token=Token.Docstring),
+                            #lexer=PythonLexer,
+                        ),
+                        height=D(max=12)),
+                    filter=HasSignature(python_input) & ShowDocstring(python_input) & ~IsDone(),
+                ),
+            ]),
+            HSplit([
+                python_sidebar(python_input),
+                python_sidebar_navigation(python_input),
+            ])
+        ]),
+    ] + extra_toolbars + [
+        VSplit([
+            status_bar(python_input),
+            show_sidebar_button_info(python_input),
+        ])
+    ])
